@@ -21,7 +21,7 @@ sub _db_add_schema_patch ( $self, $dbh ) {
                 "name" TEXT NOT NULL UNIQUE,
                 "hash" BLOB NOT NULL,
                 "enabled" INTEGER NOT NULL DEFAULT 0,
-                "created_ts" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT))
+                "created" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT))
             );
 
             -- USER PERMISSION
@@ -39,7 +39,7 @@ sub _db_add_schema_patch ( $self, $dbh ) {
                 "user_id" BLOB NOT NULL REFERENCES "api_user" ("id") ON DELETE CASCADE,
                 "hash" BLOB NOT NULL,
                 "desc" TEXT,
-                "created_ts" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT))
+                "created" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT))
             );
 
             -- USER TOKEN PERMISSION
@@ -55,8 +55,8 @@ sub _db_add_schema_patch ( $self, $dbh ) {
                 "id" BLOB PRIMARY KEY NOT NULL DEFAULT(UUID()),
                 "user_id" BLOB NOT NULL REFERENCES "api_user" ("id") ON DELETE CASCADE,
                 "hash" BLOB NOT NULL,
-                "created_ts" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT)),
-                "updated_ts" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT)),
+                "created" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT)),
+                "updated" INTEGER NOT NULL DEFAULT(CAST(STRFTIME('%s', 'now') AS INT)),
                 "ip" BLOB NOT NULL,
                 "agent" TEXT NOT NULL
             );
