@@ -2,12 +2,14 @@ package Pcore::Core::Event::Listener::Pipe::file;
 
 use Pcore -class, -ansi, -const;
 use Pcore::Util::Data qw[to_json];
+use Pcore::Util::Scalar qw[is_ref];
 use Fcntl qw[:flock];
 use IO::File;
+use Time::HiRes qw[];
 
 with qw[Pcore::Core::Event::Listener::Pipe];
 
-has tmpl => ( is => 'ro', isa => Str, default => '[<: $date.strftime("%Y-%m-%d %H:%M:%S.%4N") :>][<: $channel :>][<: $level :>] <: $title | raw :><: $text | raw :>' );
+has tmpl => ( is => 'ro', isa => Str, default => '[<: $date.strftime("%Y-%m-%d %H:%M:%S.%4N") :>][<: $channel :>][<: $level :>] <: $title | raw :>' . $LF . '<: $text | raw :>' );
 
 has _tmpl => ( is => 'ro', isa => InstanceOf ['Pcore::Util::Template'], init_arg => undef );
 has _path => ( is => 'ro', isa => InstanceOf ['Pcore::Util::Path'],     init_arg => undef );
@@ -51,7 +53,7 @@ sub sendlog ( $self, $ev ) {
     # sendlog
     {
         # prepare date object
-        local $ev->{date} = P->date->from_epoch( $ev->{timestamp} );
+        local $ev->{date} = P->date->from_epoch( $ev->{timestamp} // Time::HiRes::time() );
 
         # prepare text
         local $ev->{text};
@@ -59,13 +61,13 @@ sub sendlog ( $self, $ev ) {
         if ( defined $ev->{data} ) {
 
             # serialize reference
-            $ev->{text} = $LF . ( ref $ev->{data} ? to_json( $ev->{data}, readable => 1 )->$* : $ev->{data} );
+            $ev->{text} = is_ref $ev->{data} ? to_json( $ev->{data}, readable => 1 )->$* : $ev->{data};
 
             # indent
             $ev->{text} =~ s/^/$INDENT/smg;
 
             # remove all trailing "\n"
-            local $/ = '';
+            local $/ = q[];
 
             chomp $ev->{text};
         }
@@ -89,13 +91,11 @@ sub sendlog ( $self, $ev ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 57                   | Variables::RequireInitializationForLocalVars - "local" variable not initialized                                |
+## |    3 | 59                   | Variables::RequireInitializationForLocalVars - "local" variable not initialized                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 54, 57               | Variables::ProhibitLocalVars - Variable declared as "local"                                                    |
+## |    2 | 56, 59               | Variables::ProhibitLocalVars - Variable declared as "local"                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 68                   | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
-## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 10                   | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
+## |    1 | 12                   | ValuesAndExpressions::RequireInterpolationOfMetachars - String *may* require interpolation                     |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
