@@ -287,7 +287,7 @@ sub _create_sigchild ( $self, $win32_alive_timeout ) {
             if ( $status != Win32::Process::STILL_ACTIVE() ) {
                 undef $self->{_sigchild};    # remove timer
 
-                AE::postpone { $self->_on_exit($status) };
+                $self->_on_exit($status);
             }
 
             return;
@@ -297,7 +297,7 @@ sub _create_sigchild ( $self, $win32_alive_timeout ) {
         $self->{_sigchild} = AE::child $self->pid, sub ( $pid, $status ) {
             undef $self->{_sigchild};        # remove timer
 
-            AE::postpone { $self->_on_exit( $status >> 8 ) };
+            $self->_on_exit( $status >> 8 );
 
             return;
         };
